from opet.api import OpetApiClient
import click


@click.command()
@click.option("--il", default="34", help="Yakıt fiyatlarını öğrenmek istediğiniz ilin plaka kodunu giriniz.")
def cli(il):
    client = OpetApiClient()
    try:
        print(client.price(il))
    except Exception as e:
        print(e)



from datetime import datetime, timezone, timedelta
import requests
from opet.exceptions import Http200Error
import json


def yesterday():
    now_datetime = datetime.now(timezone.utc)
    six_hours_delta = timedelta(days=1)
    target_datetime = now_datetime - six_hours_delta
    output_datetime_str = target_datetime.strftime('%Y-%m-%dT%H:%M:%S.%fZ')
    return output_datetime_str


def http_get(url):
    headers = {
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36',
        'Origin': 'https://www.opet.com.tr',
        'Host': 'api.opet.com.tr',
        'Channel': 'Web',
        'Accept-Language': 'tr-TR'
    }
    r = requests.get(url, headers=headers, verify=True)
    if r.status_code != 200:
        raise Http200Error("HttpStatusCode is not 200.")
    return r.json()


def to_json(data):
    return json.dumps(data, ensure_ascii=False, indent=2)


if __name__ == '__main__':
    print(yesterday())



from opet.utils import yesterday, http_get, to_json
from opet.exceptions import ProvinceNotFoundError

class OpetApiClient:
    def __init__(self):
        self.url = "https://api.opet.com.tr/api/fuelprices"

    def get_provinces(self):
        return http_get(f"{self.url}/provinces")

    def get_districts(self, province_id):
        return http_get(f"{self.url}/provinces/{province_id}/districts")

    def get_price(self, district_id: str):
        date = yesterday()
        url = f"{self.url}/prices/archive?DistrictCode={district_id}&StartDate={date}&EndDate={date}&IncludeAllProducts=true"
        r = http_get(url)
        response = list(map(lambda x: dict(name=x["productName"], amount=x["amount"]), r[0]["prices"]))
        return response

    def price(self, province_id: str):
        _provinces = self.get_provinces()
        formatted_provinces = {str(item['code']): item['name'] for item in _provinces}
        province_name = formatted_provinces.get(f"{province_id}", None)
        if province_name is None:
            raise ProvinceNotFoundError(f"Sistemde {province_id} plaka koduna ait bir il bulunamadı.")

        result = dict(
            results=dict(
                province=province_name,
                prices=self.get_price(self.get_districts(province_id)[0]["code"])
            )
        )
        return to_json(result)


if __name__ == '__main__':
    client = OpetApiClient()
    print(client.price("28"))



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="opet",
    author="Sinan Erdinc",
    author_email="hello@sinanerdinc.com",
    version="0.0.8",
    install_requires=["requests", "click"],
    description="A Python package that allows you to view fuel prices in Turkey based on cities.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/sinanerdinc/opet",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={
        'console_scripts': [
            'opet-cli=opet.main:cli',
        ],
    },
    packages=find_packages(),
    package_dir={'opet': 'opet'},
    python_requires=">=3.0"
)
